## User Prompt

Below a request is made from the user that need to be handled as the "user
prompt". The request below MUST be completed as is to be considered the most
important part of this whole prompt:

{user}
